Welcome to Alembic’s documentation! — Alembic v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- Alembic v0.1.0 documentation »

# Welcome to Alembic’s documentation!

Alembic is a lightweight database migration tool for usage with the SQLAlchemy Database Toolkit for Python.

- Front Matter
  - Project Homepage
  - Project Status
  - Installation
  - Community
  - Bugs
- Tutorial
  - The Migration Environment
  - Creating an Environment
  - Editing the .ini File
  - Create a Migration Script
  - Running our First Migration
  - Running our Second Migration
  - Getting Information
  - Downgrading
  - Auto Generating Migrations
  - Generating SQL Scripts (a.k.a. “Offline Mode”)
  - Working with Branches
  - Building an Up to Date Database from Scratch
- Operation Reference
- API Details
  - env.py Directives
  - Commands
  - Configuration
  - Internals

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Alembic v0.1.0 documentation »